﻿#region Copyright (C) 2005-2010 Team MediaPortal

// Copyright (C) 2005-2010 Team MediaPortal
// http://www.team-mediaportal.com
// 
// MediaPortal is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 2 of the License, or
// (at your option) any later version.
// 
// MediaPortal is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with MediaPortal. If not, see <http://www.gnu.org/licenses/>.

#endregion

using System;
using System.IO;
using System.Xml;
using System.Net;
using System.Globalization;
using System.Collections.Generic;
using System.Runtime.CompilerServices;
using System.Threading;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using MediaPortal.Dialogs;
using MediaPortal.GUI.Library;
using MediaPortal.Configuration;
using MediaPortal.Util;

namespace yrWeather
{
    public class GUIyrWeather : GUIInternalWindow, ISetupForm, IShowPlugin
    {
        #region structs

        private struct Forecast
        {
            public DateTime Date;
            public ForecastData Night;
            public ForecastData AM;
            public ForecastData PM;
            public ForecastData Evening;
        }

        private struct ForecastData
        {
            public int type;
            public string precipitation;
            public string windDir;
            public string windSpeed;
            public string temperature;
            public bool dataExists;
        } ;
        
        #endregion

        #region enums

        private enum Controls
        {
            CONTROL_BTNSWITCH = 2,
            CONTROL_LBLWEEKDAY = 3,
            CONTROL_LBLDATE = 4,
            CONTROL_LBLLOCATION = 5,
            CONTROL_LBLNIGHTTEMPERATURESTATIC = 10,
            CONTROL_LBLNIGHTTEMPERATURE = 11,
            CONTROL_LBLNIGHTWINDSTATIC = 12,
            CONTROL_LBLNIGHTWIND = 13,
            CONTROL_LBLNIGHTPRECIPTATIONSTATIC = 14,
            CONTROL_LBLNIGHTPRECIPTATION = 15,
            CONTROL_IMGNIGHTCURRENTWEATHERICON = 16,
            CONTROL_LBLNIGHTSTATIC = 17,
            CONTROL_LBLNIGHTTYPEWEATHER = 18,
            CONTROL_LBLAMTEMPERATURESTATIC = 20,
            CONTROL_LBLAMTEMPERATURE = 21,
            CONTROL_LBLAMWINDSTATIC = 22,
            CONTROL_LBLAMWIND = 23,
            CONTROL_LBLAMPRECIPTATIONSTATIC = 24,
            CONTROL_LBLAMPRECIPTATION = 25,
            CONTROL_IMGAMCURRENTWEATHERICON = 26,
            CONTROL_LBLAMSTATIC = 27,
            CONTROL_LBLAMTYPEWEATHER = 28,
            CONTROL_LBLPMTEMPERATURESTATIC = 30,
            CONTROL_LBLPMTEMPERATURE = 31,
            CONTROL_LBLPMWINDSTATIC = 32,
            CONTROL_LBLPMWIND = 33,
            CONTROL_LBLPMPRECIPTATIONSTATIC = 34,
            CONTROL_LBLPMPRECIPTATION = 35,
            CONTROL_IMGPMCURRENTWEATHERICON = 36,
            CONTROL_LBLPMSTATIC = 37,
            CONTROL_LBLPMTYPEWEATHER = 38,
            CONTROL_LBLEVENINGTEMPERATURESTATIC = 40,
            CONTROL_LBLEVENINGTEMPERATURE = 41,
            CONTROL_LBLEVENINGWINDSTATIC = 42,
            CONTROL_LBLEVENINGWIND = 43,
            CONTROL_LBLEVENINGPRECIPTATIONSTATIC = 44,
            CONTROL_LBLEVENINGPRECIPTATION = 45,
            CONTROL_IMGEVENINGCURRENTWEATHERICON = 46,
            CONTROL_LBLEVENINGSTATIC = 47,
            CONTROL_LBLEVENINGTYPEWEATHER = 48
        }

        #endregion

        #region variables

        private string _urlLocation;

        private string _location;

        private const string _naIcon = @"weather\128x128\na.png";

        private const string _naString = "???";

        private const string _celsiusString = "°C";

        private const string _milimeterString = "mm";

        private List<Forecast> _forecastEachDay = new List<Forecast>();

        private int _actualDay = 0;

        private bool _downloadOk = false;

        #endregion

        #region Constructor

        public GUIyrWeather()
        {

        }

        #endregion

        #region Serialisation

        private void LoadSettings()
        {
            using (MediaPortal.Profile.Settings xmlreader = new MediaPortal.Profile.MPSettings())
            {
                _urlLocation = xmlreader.GetValueAsString("yrWeather", "location", string.Empty);
            }
        }

        #endregion

        #region Overrides

        public override void Process()
        {
        }

        public override void Render(float timePassed)
        {
            base.Render(timePassed);
        }

        public override bool Init()
        {
            return Load(GUIGraphicsContext.Skin + @"\yrWeather.xml");
        }

        public override void OnAction(MediaPortal.GUI.Library.Action action)
        {
            switch (action.wID)
            {
                case MediaPortal.GUI.Library.Action.ActionType.ACTION_PREVIOUS_MENU:
                    {
                        GUIWindowManager.ShowPreviousWindow();
                        return;
                    }
            }
            base.OnAction(action);
        }

        protected override void OnPageLoad()
        {
            base.OnPageLoad();
            LoadSettings();
            RefreshMe();
            SetWeatherControls();
        }

        protected override void OnPageDestroy(int new_windowId)
        {
            base.OnPageDestroy(new_windowId);
        }

        public override bool OnMessage(GUIMessage message)
        {
            switch (message.Message)
            {
                case GUIMessage.MessageType.GUI_MSG_CLICKED:
                    {
                        int iControl = message.SenderControlId;

                        if (iControl == (int)Controls.CONTROL_BTNSWITCH)
                            OnNextDay();
                    }
                    break;
            }
            return base.OnMessage(message);
        }

        public override int GetID
        {
            get
            {
                return GetWindowId();
            }
        }
        #endregion

        #region Control events

        private void OnNextDay()
        {
            _actualDay++;
            if (_actualDay >= _forecastEachDay.Count)
                _actualDay = 0;

            SetWeatherControls();
        }

        #endregion

        #region Skin control methods

        private void SetWeatherControls()
        {
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_BTNSWITCH, GUILocalizeStrings.Get(19009) + " " + GUILocalizeStrings.Get(3014));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTTEMPERATURESTATIC, GUILocalizeStrings.Get(1954));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTWINDSTATIC, GUILocalizeStrings.Get(404));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTPRECIPTATIONSTATIC, GUILocalizeStrings.Get(748));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTSTATIC, "Night");

            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMTEMPERATURESTATIC, GUILocalizeStrings.Get(1954));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMWINDSTATIC, GUILocalizeStrings.Get(404));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMPRECIPTATIONSTATIC, GUILocalizeStrings.Get(748));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMSTATIC, "AM");

            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMTEMPERATURESTATIC, GUILocalizeStrings.Get(1954));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMWINDSTATIC, GUILocalizeStrings.Get(404));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMPRECIPTATIONSTATIC, GUILocalizeStrings.Get(748));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMSTATIC, "PM");

            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGTEMPERATURESTATIC, GUILocalizeStrings.Get(1954));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGWINDSTATIC, GUILocalizeStrings.Get(404));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGPRECIPTATIONSTATIC, GUILocalizeStrings.Get(748));
            GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGSTATIC, "Evening");

            if (_downloadOk)
            {
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLWEEKDAY, LocalizeDay(_forecastEachDay[_actualDay].Date.DayOfWeek));
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLDATE, _forecastEachDay[_actualDay].Date.Day.ToString() + " " + GUILocalizeStrings.Get(20 + _forecastEachDay[_actualDay].Date.Month));
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLLOCATION, GUILocalizeStrings.Get(1028) + ": " + _location);

                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTTEMPERATURE, _forecastEachDay[_actualDay].Night.dataExists ? _forecastEachDay[_actualDay].Night.temperature : _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTWIND, _forecastEachDay[_actualDay].Night.dataExists ? _forecastEachDay[_actualDay].Night.windSpeed + " " 
                    + GUILocalizeStrings.Get(564) + " " 
                    + GUILocalizeStrings.Get(1024) + " " 
                    + LocalizeWindDirection(_forecastEachDay[_actualDay].Night.windDir) : _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTPRECIPTATION, _forecastEachDay[_actualDay].Night.dataExists ? _forecastEachDay[_actualDay].Night.precipitation + " " + _milimeterString : _naString);
                GUIImage image = (GUIImage)GetControl((int)Controls.CONTROL_IMGNIGHTCURRENTWEATHERICON);
                image.SetFileName(_forecastEachDay[_actualDay].Night.dataExists ? ParseWeatherIcon(_forecastEachDay[_actualDay].Night.type, true) : _naIcon);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTTYPEWEATHER, ParseWeatherString(_forecastEachDay[_actualDay].Night.type, true));

                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMTEMPERATURE, _forecastEachDay[_actualDay].AM.dataExists ? _forecastEachDay[_actualDay].AM.temperature : _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMWIND, _forecastEachDay[_actualDay].AM.dataExists ? _forecastEachDay[_actualDay].AM.windSpeed + " "
                    + GUILocalizeStrings.Get(564) + " "
                    + GUILocalizeStrings.Get(1024) + " "
                    + LocalizeWindDirection(_forecastEachDay[_actualDay].AM.windDir) : _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMPRECIPTATION, _forecastEachDay[_actualDay].AM.dataExists ? _forecastEachDay[_actualDay].AM.precipitation + " " + _milimeterString : _naString);
                image = (GUIImage)GetControl((int)Controls.CONTROL_IMGAMCURRENTWEATHERICON);
                image.SetFileName(_forecastEachDay[_actualDay].AM.dataExists ? ParseWeatherIcon(_forecastEachDay[_actualDay].AM.type, false) : _naIcon);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMTYPEWEATHER, ParseWeatherString(_forecastEachDay[_actualDay].AM.type, false));

                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMTEMPERATURE, _forecastEachDay[_actualDay].PM.dataExists ? _forecastEachDay[_actualDay].PM.temperature : _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMWIND, _forecastEachDay[_actualDay].PM.dataExists ? _forecastEachDay[_actualDay].PM.windSpeed + " "
                    + GUILocalizeStrings.Get(564) + " "
                    + GUILocalizeStrings.Get(1024) + " "
                    + LocalizeWindDirection(_forecastEachDay[_actualDay].PM.windDir) : _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMPRECIPTATION, _forecastEachDay[_actualDay].PM.dataExists ? _forecastEachDay[_actualDay].PM.precipitation + " " + _milimeterString : _naString);
                image = (GUIImage)GetControl((int)Controls.CONTROL_IMGPMCURRENTWEATHERICON);
                image.SetFileName(_forecastEachDay[_actualDay].PM.dataExists ? ParseWeatherIcon(_forecastEachDay[_actualDay].PM.type, false) : _naIcon);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMTYPEWEATHER, ParseWeatherString(_forecastEachDay[_actualDay].PM.type, false));
                
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGTEMPERATURE, _forecastEachDay[_actualDay].Evening.dataExists ? _forecastEachDay[_actualDay].Evening.temperature : _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGWIND, _forecastEachDay[_actualDay].Evening.dataExists ? _forecastEachDay[_actualDay].Evening.windSpeed + " "
                    + GUILocalizeStrings.Get(564) + " "
                    + GUILocalizeStrings.Get(1024) + " "
                    + LocalizeWindDirection(_forecastEachDay[_actualDay].Evening.windDir) : _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGPRECIPTATION, _forecastEachDay[_actualDay].Evening.dataExists ? _forecastEachDay[_actualDay].Evening.precipitation + " " + _milimeterString : _naString);
                image = (GUIImage)GetControl((int)Controls.CONTROL_IMGEVENINGCURRENTWEATHERICON);
                image.SetFileName(_forecastEachDay[_actualDay].Evening.dataExists ? ParseWeatherIcon(_forecastEachDay[_actualDay].Evening.type, true) : _naIcon);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGTYPEWEATHER, ParseWeatherString(_forecastEachDay[_actualDay].Evening.type, false));
            }
            else
            {           
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLWEEKDAY, _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLDATE, _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLLOCATION, GUILocalizeStrings.Get(1028) + ": " + _naString);

                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTTEMPERATURE, _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTWIND, _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTPRECIPTATION, _naString);
                GUIImage image = (GUIImage)GetControl((int)Controls.CONTROL_IMGNIGHTCURRENTWEATHERICON);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLNIGHTTYPEWEATHER, _naString);
                image.SetFileName(_naIcon);

                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMTEMPERATURE, _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMWIND, _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMPRECIPTATION, _naString);
                image = (GUIImage)GetControl((int)Controls.CONTROL_IMGAMCURRENTWEATHERICON);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLAMTYPEWEATHER, _naString);
                image.SetFileName(_naIcon);

                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMTEMPERATURE, _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMWIND, _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMPRECIPTATION, _naString);
                image = (GUIImage)GetControl((int)Controls.CONTROL_IMGPMCURRENTWEATHERICON);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLPMTYPEWEATHER, _naString);
                image.SetFileName(_naIcon);

                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGTEMPERATURE, _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGWIND, _naString);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGPRECIPTATION, _naString);
                image = (GUIImage)GetControl((int)Controls.CONTROL_IMGEVENINGCURRENTWEATHERICON);
                GUIControl.SetControlLabel(GetID, (int)Controls.CONTROL_LBLEVENINGTYPEWEATHER, _naString);
                image.SetFileName(_naIcon);
            }

        }

        #endregion

        #region Main refresh method
        //Do a complete download, parse and update
        private void RefreshMe()
        {
                using (WaitCursor cursor = new WaitCursor())
                {
                    //message strings for refresh of images
                    if (!Directory.Exists(Config.GetFolder(Config.Dir.Cache)))
                    {
                        Directory.CreateDirectory(Config.GetFolder(Config.Dir.Cache));
                    }

                    string weatherFile = Config.GetFile(Config.Dir.Cache, "curYrWeather.xml");

                    bool dlRes = false, ldRes = false;
                    //Do The Download
                    dlRes = Download(weatherFile);

                    if (dlRes) //dont load if download failed
                    {
                        ldRes = ParseWeatherInfoFromFile(weatherFile); //parse
                    }

                    //if the download or load failed, display an error message
                    if (!dlRes || !ldRes) //this will probably crash on an autoupdate as well, but not tested
                    {
                        // show failed dialog...
                        GUIDialogOK errorDialog = (GUIDialogOK)GUIWindowManager.GetWindow((int)Window.WINDOW_DIALOG_OK);
                        errorDialog.SetHeading(412); //"Unable to get weather data"
                        errorDialog.SetLine(1, string.Empty);
                        errorDialog.SetLine(2, string.Empty);
                        errorDialog.SetLine(3, string.Empty);
                        errorDialog.DoModal(GetID);                        
                    }
                    else
                        _downloadOk = true;
                }
        }

        #endregion

        #region Web download

        private bool Download(string weatherFile)
        {
            using (WebClient client = new WebClient())
            {
                try
                {
                    client.Proxy.Credentials = CredentialCache.DefaultCredentials;
                    client.DownloadFile(_urlLocation + "forecast.xml", weatherFile);
                    return true;
                }
                catch (Exception ex)
                {
                    Log.Info("Failed to download weather: {0} {1}", ex.Message, ex.Source);
                }
            }
            return false;
        }

        #endregion

        #region XML Parsing

        private bool ParseWeatherInfoFromFile(string weatherFile)
        {          
            if (File.Exists(weatherFile))
            {
                try
                {
                    XmlDocument doc = new XmlDocument();
                    doc.Load(weatherFile);
                    XmlNode root = doc.DocumentElement;

                    XmlNode location = root.SelectSingleNode("location");
                    XmlElement locationName = (XmlElement)location.SelectSingleNode("name");
                    _location = locationName.InnerText;

                    XmlNode forecastNode = root.SelectSingleNode("forecast");
                    XmlNode tabularNode = forecastNode.SelectSingleNode("tabular");
                    
                    Forecast forecast = new Forecast();
                    int prevDay = 0;
                    foreach(XmlNode time in tabularNode.ChildNodes)
                    {
                        string dateString = ((XmlAttribute)time.Attributes.GetNamedItem("from")).Value;
                        dateString.Replace('T',' ');
                        DateTime date = DateTime.Parse(dateString);
                        if (date.Day != prevDay)
                        {
                            if (prevDay != 0)
                                _forecastEachDay.Add(forecast);
                            forecast = new Forecast();
                            forecast.Date = date;
                        }

                        ForecastData forecastData = new ForecastData();

                        XmlNode symbol = time.SelectSingleNode("symbol");
                        forecastData.type = int.Parse(symbol.Attributes.GetNamedItem("number").Value);
                        
                        XmlNode precipitation = time.SelectSingleNode("precipitation");
                        forecastData.precipitation = precipitation.Attributes.GetNamedItem("value").Value;
                        
                        XmlNode windDirection = time.SelectSingleNode("windDirection");
                        forecastData.windDir = windDirection.Attributes.GetNamedItem("code").Value;

                        XmlNode windSpeed = time.SelectSingleNode("windSpeed");
                        forecastData.windSpeed = windSpeed.Attributes.GetNamedItem("mps").Value;

                        XmlNode temperature = time.SelectSingleNode("temperature");
                        forecastData.temperature = temperature.Attributes.GetNamedItem("value").Value;

                        forecastData.dataExists = true;

                        switch (int.Parse(time.Attributes.GetNamedItem("period").Value))
                        {
                            case 0:
                                forecast.Night = forecastData;
                                break;

                            case 1:
                                forecast.AM = forecastData;
                                break;

                            case 2:
                                forecast.PM = forecastData;
                                break;

                            case 3:
                                forecast.Evening = forecastData;
                                break;
                        }
                        prevDay = date.Day;                               
                    }
                    _forecastEachDay.Add(forecast);
                }
                catch (Exception e)
                {
                    Log.Error(e);
                    return false;
                }
                return true;
            }
            else
                return false;
        }

        #endregion

        #region Parsing

        private string ParseWeatherIcon(int symbol, bool dark)
        {
            string icon = _naIcon;

            if(symbol == 1 && !dark)
                icon = @"weather\128x128\32.png";
            else if (symbol == 1 && dark)
                icon = @"weather\128x128\31.png";
            else if (symbol == 2 && !dark)
                icon = @"weather\128x128\30.png";
            else if (symbol == 2 && dark)
                icon = @"weather\128x128\29.png";
            else if (symbol == 3 && !dark)
                icon = @"weather\128x128\28.png";
            else if (symbol == 3 && dark)
                icon = @"weather\128x128\27.png";
            else if (symbol == 4 && !dark)
                icon = @"weather\128x128\26.png";
            else if (symbol == 4 && dark)
                icon = @"weather\128x128\26.png";
            else if (symbol == 5 && !dark)
                icon = @"weather\128x128\11.png";
            else if (symbol == 5 && dark)
                icon = @"weather\128x128\11.png";
            else if (symbol == 6 && !dark)
                icon = @"weather\128x128\17.png";
            else if (symbol == 6 && dark)
                icon = @"weather\128x128\17.png";
            else if (symbol == 7 && !dark)
                icon = @"weather\128x128\5.png";
            else if (symbol == 7 && dark)
                icon = @"weather\128x128\5.png";
            else if (symbol == 8 && !dark)
                icon = @"weather\128x128\13.png";
            else if (symbol == 8 && dark)
                icon = @"weather\128x128\13.png";
            else if (symbol == 9 && !dark)
                icon = @"weather\128x128\12.png";
            else if (symbol == 9 && dark)
                icon = @"weather\128x128\12.png";
            else if (symbol == 10 && !dark)
                icon = @"weather\128x128\10.png";
            else if (symbol == 10 && dark)
                icon = @"weather\128x128\10.png";
            else if (symbol == 11 && !dark)
                icon = @"weather\128x128\4.png";
            else if (symbol == 11 && dark)
                icon = @"weather\128x128\4.png";
            else if (symbol == 12 && !dark)
                icon = @"weather\128x128\5.png";
            else if (symbol == 12 && dark)
                icon = @"weather\128x128\5.png";
            else if (symbol == 13 && !dark)
                icon = @"weather\128x128\16.png";
            else if (symbol == 13 && dark)
                icon = @"weather\128x128\16.png";
            else if (symbol == 14 && !dark)
                icon = @"weather\128x128\3.png";
            else if (symbol == 14 && dark)
                icon = @"weather\128x128\3.png";
            else if (symbol == 15 && !dark)
                icon = @"weather\128x128\34.png";
            else if (symbol == 15 && dark)
                icon = @"weather\128x128\33.png";

            return icon;
        }

        private string ParseWeatherString(int symbol, bool dark)
        {
            string parseString = "Unknown weather";

            if (symbol == 1 && !dark)
                parseString = String.Format("{0} {1} {2}", GUILocalizeStrings.Get(386), GUILocalizeStrings.Get(388), GUILocalizeStrings.Get(373));
            else if (symbol == 1 && dark)
                parseString = GUILocalizeStrings.Get(386);
            else if (symbol == 2)
                parseString = String.Format("{0} {1}", GUILocalizeStrings.Get(371), GUILocalizeStrings.Get(374));
            else if (symbol == 3)
                parseString = String.Format("{0} {1}", GUILocalizeStrings.Get(372), GUILocalizeStrings.Get(374));
            else if (symbol == 4)
                parseString = GUILocalizeStrings.Get(374);
            else if (symbol == 5)
                parseString = String.Format("{0} {1}", GUILocalizeStrings.Get(382), GUILocalizeStrings.Get(380));
            else if (symbol == 6)
                parseString = String.Format("{0} {1} {2} {3}", GUILocalizeStrings.Get(382), GUILocalizeStrings.Get(380), GUILocalizeStrings.Get(388), GUILocalizeStrings.Get(370));
            else if (symbol == 7)
                parseString = String.Format("{0} {1} {2} {3}", GUILocalizeStrings.Get(382), GUILocalizeStrings.Get(380), GUILocalizeStrings.Get(388), GUILocalizeStrings.Get(375));
            else if (symbol == 8)
                parseString = String.Format("{0} {1}", GUILocalizeStrings.Get(371), GUILocalizeStrings.Get(375));
            else if (symbol == 9)
                parseString = GUILocalizeStrings.Get(376);
            else if (symbol == 10)
                parseString = GUILocalizeStrings.Get(376);
            else if (symbol == 11)
                parseString = String.Format("{0} {1} {2}", GUILocalizeStrings.Get(376), GUILocalizeStrings.Get(388), GUILocalizeStrings.Get(370));
            else if (symbol == 12)
                parseString = String.Format("{0} {1} {2}", GUILocalizeStrings.Get(376), GUILocalizeStrings.Get(388), GUILocalizeStrings.Get(375));
            else if (symbol == 13)
                parseString = GUILocalizeStrings.Get(375);
            else if (symbol == 14)
                parseString = String.Format("{0} {1} {2}", GUILocalizeStrings.Get(375), GUILocalizeStrings.Get(388), GUILocalizeStrings.Get(370));
            else if (symbol == 15)
                parseString = GUILocalizeStrings.Get(389);
            return parseString;
        }

        #endregion

        #region Localisation

        private string LocalizeDay(DayOfWeek dayOfWeek)
        {
            string localizedDay = string.Empty;

            if (dayOfWeek == DayOfWeek.Monday)
            {
                localizedDay = GUILocalizeStrings.Get(11);
            }
            else if (dayOfWeek == DayOfWeek.Tuesday)
            {
                localizedDay = GUILocalizeStrings.Get(12);
            }
            else if (dayOfWeek == DayOfWeek.Wednesday)
            {
                localizedDay = GUILocalizeStrings.Get(13);
            }
            else if (dayOfWeek == DayOfWeek.Thursday)
            {
                localizedDay = GUILocalizeStrings.Get(14);
            }
            else if (dayOfWeek == DayOfWeek.Friday)
            {
                localizedDay = GUILocalizeStrings.Get(15);
            }
            else if (dayOfWeek == DayOfWeek.Saturday)
            {
                localizedDay = GUILocalizeStrings.Get(16);
            }
            else if (dayOfWeek == DayOfWeek.Sunday)
            {
                localizedDay = GUILocalizeStrings.Get(17);
            }
            else
            {
                localizedDay = string.Empty;
            }

            return localizedDay;
        }

        private string LocalizeWindDirection(string direction)
        {
            string localizedWindDirection = string.Empty;

            if (direction == "N")
                localizedWindDirection = GUILocalizeStrings.Get(535);
            else if (direction == "NNE")
                localizedWindDirection = GUILocalizeStrings.Get(544);
            else if (direction == "NE")
                localizedWindDirection = GUILocalizeStrings.Get(539);
            else if (direction == "ENE")
                localizedWindDirection = GUILocalizeStrings.Get(545);
            else if (direction == "E")
                localizedWindDirection = GUILocalizeStrings.Get(536);
            else if (direction == "ESE")
                localizedWindDirection = GUILocalizeStrings.Get(546);
            else if (direction == "SE")
                localizedWindDirection = GUILocalizeStrings.Get(540);
            else if (direction == "SSE")
                localizedWindDirection = GUILocalizeStrings.Get(547);
            else if (direction == "S")
                localizedWindDirection = GUILocalizeStrings.Get(537);
            else if (direction == "SSW")
                localizedWindDirection = GUILocalizeStrings.Get(548);
            else if (direction == "SW")
                localizedWindDirection = GUILocalizeStrings.Get(541);
            else if (direction == "WSW")
                localizedWindDirection = GUILocalizeStrings.Get(549);
            else if (direction == "W")
                localizedWindDirection = GUILocalizeStrings.Get(538);
            else if (direction == "WNW")
                localizedWindDirection = GUILocalizeStrings.Get(551);
            else if (direction == "NW")
                localizedWindDirection = GUILocalizeStrings.Get(542);
            else if (direction == "NNW")
                localizedWindDirection = GUILocalizeStrings.Get(552);
            else
                localizedWindDirection = string.Empty;

            return localizedWindDirection;
        }

        #endregion

        #region ISetupForm Members

        public bool CanEnable()
        {
            return true;
        }

        public string PluginName()
        {
            return "yrWeather";
        }

        public bool DefaultEnabled()
        {
            return false;
        }

        public bool HasSetup()
        {
            return true;
        }

        public int GetWindowId()
        {
            return 3231;
        }

        public bool GetHome(out string strButtonText, out string strButtonImage, out string strButtonImageFocus,
                            out string strPictureImage)
        {
            strButtonText = GUILocalizeStrings.Get(8);
            strButtonImage = string.Empty;
            strButtonImageFocus = string.Empty;
            strPictureImage = @"hover_my weather.png";
            return true;
        }

        public string Author()
        {
            return "Mathias Carlsson";
        }

        public string Description()
        {
            return "Shows weather data from yr.no";
        }

        public void ShowPlugin()
        {
            new Settings().Show();
        }

        #endregion

        #region IShowPlugin Members

        public bool ShowDefaultHome()
        {
            return true;
        }

        #endregion
    }
}
